#!/usr/bin/bash

if ! jq --version &> /dev/null; then
    echo "You need to install jq to run this script"
    exit 1
fi

if [ ! "$1" ]; then
    echo "Please specify format: [bird|babeld]"
    exit 1
fi

filter=

for file in *.json; do
    [[ $file =~ ^(schema.json)$ ]] && continue
    for prefix in $(jq -r ".route | keys[]" "$file"); do
        prefixlen=$(echo "$prefix" | cut -d "/" -f2)
        maxlen=$(jq -r ".route.\"$prefix\".\"max-len\"" "$file")
        if [ "$maxlen" == "null" ]; then
            maxlen=64
        fi
        if [ "$1" == "bird" ]; then
            filter="$filter$prefix{$prefixlen,$maxlen},\n"
        elif [ "$1" == "babeld" ]; then
            filter="$filter \bin ip $prefix ge $maxlen allow\n"
        fi
    done
done

if [ "$filter" == "" ]; then
    echo "Failed: Filter seems empty"
    exit 1
elif [ "$1" == "bird" ]; then
    filter=${filter::-3}
elif [ "$1" == "babeld" ]; then
    filter=${filter::-2}
fi


echo -e "$filter"
